<?php

namespace Drupal\service;

/**
 * Provides a trait for the cache service.
 */
trait CacheTrait {

  use ServiceTrait;

  /**
   * Sets the cache.
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface|null $container
   *   (optional) The service container. Defaults to NULL.
   * @param string $bin
   *   (optional) The cache name. Defaults to 'default'.
   *
   * @return $this
   */
  protected function addCache($container = NULL, $bin = 'default') {
    return $this->setKnownService($container, 'cache.' . $bin);
  }

  /**
   * Gets the cache.
   *
   * @param string $bin
   *   (optional) The cache bin for which the cache object should be returned.
   *   Defaults to 'default'.
   *
   * @return \Drupal\Core\Cache\CacheBackendInterface
   *   The cache.
   *
   * @see \Drupal::cache()
   * @see \Drupal\Core\Controller\ControllerBase::cache()
   */
  protected function cache($bin = 'default') {
    return $this->getKnownService('cache.' . $bin);
  }

}
