<?php

namespace Drupal\service;

/**
 * Provides a trait for the database connection service.
 */
trait ConnectionTrait {

  use ServiceTrait;

  /**
   * The service name.
   *
   * @var string
   */
  protected $serviceConnection = 'database';

  /**
   * The database connection.
   *
   * Prevents the database connection from being serialized.
   *
   * @var \Drupal\Core\Database\Connection
   *
   * @see \Drupal\Core\Database\Connection::__sleep()
   */
  protected $connection;

  /**
   * Sets the database connection.
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface|null $container
   *   (optional) The service container. Defaults to NULL.
   *
   * @return $this
   */
  protected function addConnection($container = NULL) {
    return $this->setKnownService($container);
  }

  /**
   * Gets the database connection based on the service class name.
   *
   * @return \Drupal\Core\Database\Connection
   *   The current active database's master connection.
   */
  protected function connection() {
    return $this->getKnownService();
  }

  /**
   * Gets the database connection based on the service identifier.
   *
   * @return \Drupal\Core\Database\Connection
   *   The current active database's master connection.
   *
   * @see \Drupal::database()
   */
  protected function database() {
    return $this->connection();
  }

}
